@@ -25,6 +25,7 @@ signals:
     void pause();
     void back();
     void list();
+    void settings();
 protected:
     void changeEvent(QEvent *e);
 private slots:
@@ -33,6 +34,7 @@ private slots:
     void on_pauseB_clicked();
     void on_backB_clicked();
     void on_list_clicked();
+    void on_settingsB_clicked();
 
 
 private:
