@@ -14,6 +14,7 @@ groove::groove(QWidget *parent) :
     //mBar->addAction("test");
     sMethod = new QPushButton("Song:");
     lineEdit = new QLineEdit("");
+    settingsWin = new settings();
     player = new sPlayer();
     QHBoxLayout *layout = new QHBoxLayout();
     QVBoxLayout *vlayout = new QVBoxLayout();
@@ -112,16 +113,33 @@ groove::groove(QWidget *parent) :
     connect(bBar,SIGNAL(addB()),this,SLOT(addSongPlaylist()));
     connect(bBar,SIGNAL(nextB()),player,SLOT(playNext()));
     connect(bBar,SIGNAL(pause()),this,SLOT(stop()));
+    connect(bBar,SIGNAL(settings()),settingsWin,SLOT(show()));
 
     connect(bBar,SIGNAL(back()),player,SLOT(back()));
+    stack->addWidget(settingsWin);
+    connect(bBar,SIGNAL(settings()),this,SLOT(toggleSettings()));
+    connect(settingsWin,SIGNAL(closed()),this,SLOT(toggleSettings()));
     bBar->setPlaybackProgress(100,100);
     pwindow = new pWin();
     stack->addWidget(pwindow);
     stack->setCurrentWidget(resultView);
     connect(bBar,SIGNAL(list()),this,SLOT(togglePlaylist()));
     pwindow->setModel(pl);
+    connect(settingsWin,SIGNAL(settingsChange(QString,QVariant)),pl,SLOT(setSettings(QString,QVariant)));
+    settingsWin->populate();
 
 }
+void groove::showSettings(){
+}
+
+void groove::toggleSettings()
+{
+    if(stack->currentWidget()==settingsWin)
+        stack->setCurrentWidget(resultView);
+    else
+        stack->setCurrentWidget(settingsWin);
+}
+
 void groove::togglePlaylist()
 {
     if(stack->currentWidget()==pwindow)
