@@ -12,6 +12,9 @@
 #include "topbar.h"
 #include "vkb.h"
 #include "bottombar.h"
+#include "settings.h"
+#include <QSettings>
+
 //#include "mpgplayer.h"
 #include "pwin.h"
 
@@ -37,11 +40,14 @@ private slots:
     void addSongPlaylist();
     void showOthers();
     void togglePlaylist();
+    void toggleSettings();
+    void showSettings();
 private:
     void resizeEvent(QResizeEvent *);
     //mpgplayer *mpg;
     bottomBar *bBar;
     sPlayer *player;
+    settings *settingsWin;
     QMenuBar *mBar;
     QPushButton *sMethod;
     QStandardItemModel *model;
