@@ -6,7 +6,8 @@
 //#include <parser.h>
 #define GSPASS "**********"
 #define GSIP "grooveshark.com"
-#define GS_LISTEN "listen.grooveshark.com"
+#define GS_LISTEN "grooveshark.com"
+#define GS_KEEPALIVE "http://grooveshark.com/sidebar.php?ThemeID=166&0=1"
 #define GS_GUTS "guts.grroveshark.com"
 class gscom : public QObject
 {
@@ -39,6 +40,7 @@ private:
         getStreamKeyFromSongIDEx,
         getPHP,
         getTokenForForSong,
+        refresh,
         none
     };
     gMETHOD currentaction;
@@ -54,6 +56,8 @@ private:
     void addProgressbar(QString debug);
     bool firstR;
     QByteArray *postdata;
+private slots:
+    void refreshsession();
 };
 
 #endif // GSCOM_H
